@@ -1,12 +1,11 @@
-from reframed.core.cbmodel import CBModel, CBReaction
-from reframed.core.model import AttrOrderedDict, Metabolite
 import copy
 
+from reframed.core.cbmodel import CBModel
 
 
 class SMomentModel(CBModel):
 
-    def __init__(self,model, enzyme_reaction_prefix = "R_ENZYME_DELIVERY_"):
+    def __init__(self, model, enzyme_reaction_prefix="R_ENZYME_DELIVERY_"):
         """SMomentModel an extension of REFRAMED CBModel for sMOMENT models.
 
         :param model: a path to a CBM xml file or an instance of REFRAMED SBModel
@@ -20,9 +19,8 @@ class SMomentModel(CBModel):
             model = load_cbmodel(model)
         elif not isinstance(model, CBModel):
             raise ValueError("The model should be a path or a CBModel")
-        
 
-        super(SMomentModel,self).__init__(model.id)
+        super(SMomentModel, self).__init__(model.id)
         self.enzyme_prefix = enzyme_reaction_prefix
         # import CBModel's data
         self.compartments = copy.deepcopy(model.compartments)
@@ -34,16 +32,13 @@ class SMomentModel(CBModel):
             if rx.startswith(self.enzyme_prefix):
                 self.enzymes.append(rx[len(self.enzyme_prefix):])
 
-
     @property
     def protein_rev_reactions(self):
         return {}
-    
 
     @property
     def proteins(self):
         return self.enzymes
-    
 
-    def set_pool_bounds(self,lb,up):
-        pass
\ No newline at end of file
+    def set_pool_bounds(self, lb, up):
+        pass
